aboutsummaryrefslogtreecommitdiff
path: root/basics/main.c
diff options
context:
space:
mode:
authorMiquel Sabaté Solà <mikisabate@gmail.com>2024-08-13 06:23:12 +0000
committerMiquel Sabaté Solà <mikisabate@gmail.com>2024-12-05 16:02:29 +0100
commit6f0ebbad84419de65a03a0ea6e41cbc6b49d6eb0 (patch)
treef5fbeb6e3f50ebb57000f9b1aac6e3ba129d6587 /basics/main.c
parent8e968078e6aee470a02bed7728100b2df1877e90 (diff)
downloadfarga-6f0ebbad84419de65a03a0ea6e41cbc6b49d6eb0.tar.gz
farga-6f0ebbad84419de65a03a0ea6e41cbc6b49d6eb0.zip
basics: Fix typo on 'palindrome'
Signed-off-by: Miquel Sabaté Solà <mikisabate@gmail.com>
Diffstat (limited to 'basics/main.c')
-rw-r--r--basics/main.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/basics/main.c b/basics/main.c
index 207fee2..89d4401 100644
--- a/basics/main.c
+++ b/basics/main.c
@@ -45,26 +45,26 @@ void test_reverse_string()
}
/*
* Returns true if the given string is a palyndrome, false otherwise.
*
* Implemented in string.S
*/
-bool is_palyndrome(char *str);
+bool is_palindrome(char *str);
-void test_is_palyndrome()
+void test_is_palindrome()
{
- assert(is_palyndrome(NULL) == 0);
- assert(is_palyndrome("") == 0);
- assert(is_palyndrome("aba") == 1);
- assert(is_palyndrome("aaa") == 1);
- assert(is_palyndrome("This is a a si sihT") == 1);
+ assert(is_palindrome(NULL) == 0);
+ assert(is_palindrome("") == 0);
+ assert(is_palindrome("aba") == 1);
+ assert(is_palindrome("aaa") == 1);
+ assert(is_palindrome("This is a a si sihT") == 1);
- printf("is_palyndrome:\tOK\n");
+ printf("is_palindrome:\tOK\n");
}
int main()
{
test_factorial();
test_reverse_string();
- test_is_palyndrome();
+ test_is_palindrome();
}
@@ -45,26 +45,26 @@ void test_reverse_string()
}
/*
- * Returns true if the given string is a palyndrome, false otherwise.
+ * Returns true if the given string is a palindrome, false otherwise.
*
* Implemented in string.S